module.exports = defineTest({
	description: 'block comments are printed correctly'
});
